@@ -18,6 +18,9 @@ from .errors import (
 from .thermostat import (
     Device,
     Measured,
+    MeasurementItem,
+    MeasurementScale,
+    MeasurementType,
     Module,
     Program,
     Setpoint,
@@ -52,6 +55,9 @@ __all__ = [
     "TimeSlot",
     "Setpoint",
     "Measured",
+    "MeasurementItem",
+    "MeasurementType",
+    "MeasurementScale",
     "SystemMode",
     "SetpointMode",
     "Token",
