@@ -24,6 +24,8 @@ _SET_MINOR_MODE_PATH = "api/setminormode"
 _SYNC_SCHEDULE_PATH = "api/syncschedule"
 _SWITCH_SCHEDULE_PATH = "api/switchschedule"
 _VAILLANT_DEVICE_TYPE = "NAVaillant"
+_VAILLANT_DATA_AMOUNT = "app"
+_VAILLANT_SYNC_DEVICE_ID = "all"
 _RESPONSE_STATUS_OK = "ok"
 _SETPOINT_DEFAULT_DURATION_MINS = 120
 
@@ -37,7 +39,7 @@ async def thermostat_client(
 ) -> AsyncGenerator[ThermostatClient, None]:
     client = AsyncClient()
     token_store = TokenStore(client_id, client_secret, token, on_token_update)
-    
+
     c = ThermostatClient(client, token_store)
 
     try:
@@ -45,6 +47,7 @@ async def thermostat_client(
     finally:
         await client.aclose()
 
+
 class ThermostatClient(BaseClient):
     """
     Client for making HTTP requests to the Netatmo API. Used for the subset of the API related to thermostats: getting thermostat data and changing thermostat modes.
@@ -73,7 +76,11 @@ class ThermostatClient(BaseClient):
         """
 
         path = _GET_THERMOSTATS_DATA_PATH
-        data = {"device_type": _VAILLANT_DEVICE_TYPE}
+        data = {
+            "device_type": _VAILLANT_DEVICE_TYPE,
+            "data_amount": _VAILLANT_DATA_AMOUNT,
+            "sync_device_id": _VAILLANT_SYNC_DEVICE_ID,
+        }
 
         body = await self._post(
             path,
@@ -261,7 +268,7 @@ class ThermostatClient(BaseClient):
             raise NonOkResponseException("Unknown response error. Check the log for more details.", path=path, data=data, body=body)
 
     def _get_setpoint_endtime(
-        self, 
+        self,
         setpoint_mode: SetpointMode,
         activate: bool,
         setpoint_endtime: datetime | None = None,
@@ -281,7 +288,7 @@ class ThermostatClient(BaseClient):
                 return round(setpoint_endtime.timestamp())
 
     def _get_setpoint_temp(
-        self, 
+        self,
         setpoint_mode: SetpointMode,
         activate: bool,
         setpoint_temp: float | None = None,
@@ -310,8 +317,13 @@ class Device:
         type: str = "",
         station_name: str = "",
         firmware: int = 0,
-        system_mode: str | None = None,
+        wifi_status: int = 0,
+        dhw: float | None = None,
+        dhw_max: float | None = None,
+        dhw_min: float | None = None,
         setpoint_default_duration: int = _SETPOINT_DEFAULT_DURATION_MINS,
+        outdoor_temperature: dict = {},
+        system_mode: str | None = None,
         setpoint_hwb: dict = {},
         modules: list[dict] = [],
         **kwargs,
@@ -322,21 +334,28 @@ class Device:
         self.type = type
         self.station_name = station_name
         self.firmware = firmware
-        self.system_mode = SystemMode(system_mode)
+        self.wifi_status = wifi_status
+        self.dhw = dhw
+        self.dhw_max = dhw_max
+        self.dhw_min = dhw_min
         self.setpoint_default_duration = setpoint_default_duration
+        self.outdoor_temperature = OutdoorTemperature(**outdoor_temperature)
+        self.system_mode = SystemMode(system_mode)
         self.setpoint_hwb = Setpoint(**setpoint_hwb)
         self.modules = [Module(**module) for module in modules]
 
     def __eq__(self, other: Device):
-        if (not isinstance(other, Device)):
+        if not isinstance(other, Device):
             return False
-        
-        return self.id == other.id and \
-            self.type == other.type and \
-            self.station_name == other.station_name and \
-            self.firmware == other.firmware and \
-            len(self.modules) == len(other.modules) and \
-            all([False for i, j in zip(self.modules, other.modules) if i != j])
+
+        return (
+            self.id == other.id
+            and self.type == other.type
+            and self.station_name == other.station_name
+            and self.firmware == other.firmware
+            and len(self.modules) == len(other.modules)
+            and all([False for i, j in zip(self.modules, other.modules) if i != j])
+        )
 
 
 class Module:
@@ -348,6 +367,7 @@ class Module:
         type: str = "",
         module_name: str = "",
         firmware: int = 0,
+        rf_status: int = 0,
         battery_percent: int = 0,
         setpoint_away: dict = {},
         setpoint_manual: dict = {},
@@ -361,6 +381,7 @@ class Module:
         self.type = type
         self.module_name = module_name
         self.firmware = firmware
+        self.rf_status = rf_status
         self.battery_percent = battery_percent
         self.setpoint_away = Setpoint(**setpoint_away)
         self.setpoint_manual = Setpoint(**setpoint_manual)
@@ -368,14 +389,15 @@ class Module:
         self.measured = Measured(**measured)
 
     def __eq__(self, other: Module):
-        if (not isinstance(other, Module)):
+        if not isinstance(other, Module):
             return False
-        
-        return self.id == other.id and \
-            self.type == other.type and \
-            self.module_name == other.module_name and \
-            self.firmware == other.firmware and \
-            self.battery_percent == other.battery_percent
+
+        return (
+            self.id == other.id
+            and self.type == other.type
+            and self.module_name == other.module_name
+            and self.firmware == other.firmware
+        )
 
 
 class Program:
@@ -397,7 +419,7 @@ class Program:
         self.timetable = [TimeSlot(**time_slot) for time_slot in timetable]
         self.name = name
         self.selected = selected
-    
+
     def get_active_zone(self) -> Zone | None:
         """Returns a currently active zone for a program."""
 
@@ -410,7 +432,7 @@ class Program:
         for zone in self.zones:
             if zone.id == zone_id:
                 return zone
-        
+
         return None
 
     def get_timeslots_for_today(self) -> list[TimeSlot]:
@@ -425,10 +447,12 @@ class Program:
         for time_slot in self.timetable:
             if time_slot.day == n.weekday():
                 if len(time_slots) == 0 and time_slot.time != time(0, 0):
-                    time_slots.append(TimeSlot(
-                        previous_time_slot_zone_id,
-                        time_slot.day * 1440,
-                    ))
+                    time_slots.append(
+                        TimeSlot(
+                            previous_time_slot_zone_id,
+                            time_slot.day * 1440,
+                        )
+                    )
                 time_slots.append(time_slot)
             previous_time_slot_zone_id = time_slot.id
 
@@ -515,11 +539,29 @@ class Setpoint:
     def __init__(
         self,
         setpoint_activate: bool = False,
+        setpoint_endtime: int | None = None,
         **kwargs,
     ) -> None:
         """Create new setpoint attribute."""
 
         self.setpoint_activate = setpoint_activate
+        if setpoint_endtime is None:
+            self.setpoint_endtime = None
+        else:
+            self.setpoint_endtime = datetime.fromtimestamp(setpoint_endtime)
+
+
+class OutdoorTemperature:
+    def __init__(
+        self,
+        te: float | None = None,
+        ti: int | None = None,
+        **kwargs,
+    ) -> None:
+        """Create new measured attribute."""
+
+        self.te = te
+        self.ti = datetime.fromtimestamp(ti)
 
 
 class Measured:
@@ -553,20 +595,18 @@ class MeasurementItem:
 
         self.beg_time = beg_time
         self.step_time = step_time
-        self.value = [
-            value_item
-            for inner_list in value
-            for value_item in inner_list
-        ]
+        self.value = [value_item for inner_list in value for value_item in inner_list]
 
     def __eq__(self, other: MeasurementItem):
-        if (not isinstance(other, MeasurementItem)):
+        if not isinstance(other, MeasurementItem):
             return False
-        
-        return self.beg_time == other.beg_time and \
-            self.step_time == other.step_time and \
-            len(self.value) == len(other.value) and \
-            all([False for i, j in zip(self.value, other.value) if i != j])
+
+        return (
+            self.beg_time == other.beg_time
+            and self.step_time == other.step_time
+            and len(self.value) == len(other.value)
+            and all([False for i, j in zip(self.value, other.value) if i != j])
+        )
 
 
 class SystemMode(Enum):
