@@ -18,11 +18,15 @@ token = Token({
 
 get_thermostats_data_request = {
     "device_type": "NAVaillant",
+    "data_amount": "app",
+    "sync_device_id": "all",
     "access_token": "12345",
 }
 
 get_thermostats_data_refreshed_request = {
     "device_type": "NAVaillant",
+    "data_amount": "app",
+    "sync_device_id": "all",
     "access_token": "67890",
 }
 
@@ -35,18 +39,27 @@ get_thermostats_data_response = {
                 "type": "type",
                 "station_name": "station_name",
                 "firmware": "firmware",
-                "system_mode": "summer",
+                "wifi_status": 60,
+                "dhw": 55,
+                "dhw_max": 65,
+                "dhw_min": 35,
                 "setpoint_default_duration": 120,
-                "setpoint_hwb": {"setpoint_activate": False},
+                "outdoor_temperature": {
+                    "te": 11,
+                    "ti": 1667636447,
+                },
+                "system_mode": "summer",
+                "setpoint_hwb": {"setpoint_activate": False, "setpoint_endtime": 1642056298},
                 "modules": [
                     {
                         "_id": "id",
                         "type": "type",
                         "module_name": "module_name",
                         "firmware": "firmware",
+                        "rf_status": 70,
                         "battery_percent": 80,
-                        "setpoint_away": {"setpoint_activate": False},
-                        "setpoint_manual": {"setpoint_activate": False},
+                        "setpoint_away": {"setpoint_activate": False, "setpoint_endtime": 1642056298},
+                        "setpoint_manual": {"setpoint_activate": False, "setpoint_endtime": 1642056298},
                         "therm_program_list": [
                             {
                                 "zones": [{"temp": 20, "id": 0, "hw": True}],
